@@ -208,6 +208,46 @@ class Users(object):
 		else:
 			return r3sponse.error_response(f"You are not signed in, error: {error}")
 
+		#
+	def send_email(self, 
+		# define uid or email to retrieve user.
+		uid=None, 
+		email=None, 
+		# the email title.
+		title="Account Activation",
+		# the html (str).
+		html="",
+	):
+
+		# check email.
+		try:
+			self.email
+		except AttributeError:
+			response = self.__initialize_email__()
+			if response["error"] != None: return response
+				
+		# get user.
+		response = self.get(uid=uid, email=email)
+		if response["error"] != None: return response
+		user = response["user"]
+		
+		# send email.
+		response = self.email.send(
+			subject=title,
+			recipients=[user.email], 
+			html=html)
+		if response["error"] != None:
+			response = self.__initialize_email__()
+			if response["error"] != None: return response
+			response = self.email.send(
+				subject=title,
+				recipients=[user.email], 
+				html=html)
+			if response["error"] != None: return response
+
+		# success.
+		return r3sponse.success_response(f"Successfully send an email to user [{user.display_name}].")
+
 		#
 	def send_code(self, 
 		# define uid or email to retrieve user.
